@@ -1,7 +1,7 @@
 from datetime import datetime
 from typing import List
 
-from sqlalchemy import Column, ForeignKey, Integer
+from sqlalchemy import Column, ForeignKey, Integer, String
 from sqlalchemy.orm import as_declarative, declared_attr, relationship
 
 from sqlalchemy_easy_softdelete.mixin import generate_soft_delete_mixin_class
@@ -15,6 +15,9 @@ class TestModelBase:
 
     id = Column(Integer, primary_key=True)
 
+    def __repr__(self):
+        return f"<{self.__class__.__name__} id={self.id}>"
+
 
 class SoftDeleteMixin(generate_soft_delete_mixin_class()):
     # for autocomplete
@@ -36,3 +39,23 @@ class SDChild(TestModelBase, SoftDeleteMixin):
         pid = f"(parent_id={self.parent_id})"
         left = f"{self.__class__.__name__} id={self.id} deleted={bool(self.deleted_at)}"
         return f"<{left:30} {pid:>15}>"
+
+
+class SDBaseRequest(
+    TestModelBase,
+    SoftDeleteMixin,
+):
+    request_type = Column(String(50))
+
+    __mapper_args__ = {
+        "polymorphic_identity": "sdbaserequest",
+        "polymorphic_on": request_type,
+    }
+
+
+class SDDerivedRequest(SDBaseRequest):
+    id: Integer = Column(Integer, ForeignKey("sdbaserequest.id"), primary_key=True)
+
+    __mapper_args__ = {
+        "polymorphic_identity": "sdderivedrequest",
+    }
